@@ -9,13 +9,13 @@ warnings.filterwarnings("ignore", category=np.VisibleDeprecationWarning)
 # library to target ingap states
 
 
-def energy_ingap_state(EO,ne=51):
+def energy_ingap_state(EO,ne=51,**kwargs):
     """Return the energy of an in-gap state given an embedding object"""
-    ev = EO.h0.get_gap(mode="valence")
-    ec = EO.h0.get_gap(mode="conduction")
+    ev = EO.H.get_gap(mode="valence")
+    ec = EO.H.get_gap(mode="conduction")
     es = np.linspace(-ev*0.95,ec*0.95,ne) # number of energies
     delta = (ev+ec)/ne # delta
-    (es,ds) = EO.multidos(es=es,delta=delta) # return DOS
+    (es,ds) = EO.multidos(es=es,delta=delta,**kwargs) # return DOS
     fd = interp1d(np.array(es),-np.array(ds),bounds_error=False,
                          fill_value=(ds[0],ds[-1]),
                         kind="quadratic")
